OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Ei saa kirjutada „config“ kausta!!",
    "This can usually be fixed by giving the web server write access to the config directory." : "Tavaliselt saad selle lahendada andes veebiserverile õigused seadistuse kausta kirjutamiseks",
    "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "Aga kui soovid, et seadistuste fail ei peaks olema veebiserveri poolt muudetav, siis palun määra seadistusvõtme „config_is_read_only“ väärtuseks true.",
    "See %s" : "Vaata %s",
    "Application %1$s is not present or has a non-compatible version with this server. Please check the apps directory." : "Rakendust „%1$s“ pole serverisse paigaldatud või pole tema versioon ühilduv selle serveriga. Palun kontrolli paigaldatud rakendusi.",
    "Sample configuration detected" : "Tuvastati näidisseaded",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Tuvastasin, et seadistuse faili kopeeritud näidisseaded. See võib lõhkuda sinu saidi ja see pole toetatud. Palun loe enne faili config.php muutmist dokumentatsiooni",
    "The page could not be found on the server." : "Seda lehte ei õnnestunud serverist leida.",
    "%s email verification" : "E-postiaadressi kinnitamine: %s",
    "Email verification" : "E-postiaadressi kinnitamine",
    "Click the following button to confirm your email." : "Oma e-postiaadressi kinnitamiseks klõpsi järgmisel nupul.",
    "Click the following link to confirm your email." : "Oma e-postiaadressi kinnitamiseks klõpsi järgmisel lingil.",
    "Confirm your email" : "Kiinita oma e-posti aadress",
    "Other activities" : "Muud tegevused",
    "%1$s and %2$s" : "%1$s ja %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s ja %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s ja %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s ja %5$s",
    "Education bundle" : "Rakenduste komplekt haridusasutustele",
    "Enterprise bundle" : "Rakenduste komplekt suurorganisatsioonidele",
    "Groupware bundle" : "Rühmatarkvara rakenduste komplekt",
    "Hub bundle" : "Rakenduste komplekt Nextcloud Hub",
    "Public sector bundle" : "Rakenduste komplekt avaliku sektori asutustele",
    "Social sharing bundle" : "Rakenduste komplekt sotsiaalmeedias jagamiseks",
    "PHP %s or higher is required." : "PHP %s või uuem on nõutav.",
    "PHP with a version lower than %s is required." : "Nõutud on PHP madalama versiooniga kui %s.",
    "%sbit or higher PHP required." : "Vajalik on %s-bitine või parem PHP versioon.",
    "The following architectures are supported: %s" : "Toetatud on järgnevad arhitektuurid: %s",
    "The following databases are supported: %s" : "Toetatud on järgnevad andmebaasid: %s",
    "The command line tool %s could not be found" : "Käsurea töövahendit %s ei leidu",
    "The library %s is not available." : " %s teek pole saadaval.",
    "Library %1$s with a version higher than %2$s is required - available version %3$s." : "Vajalik on „%1$s“ teek suurema versiooniga kui %2$s - hetkel on versioon %3$s.",
    "Library %1$s with a version lower than %2$s is required - available version %3$s." : "Vajalik on „%1$s“ teek väiksema versiooniga kui %2$s - hetkel on versioon %3$s.",
    "The following platforms are supported: %s" : "Toetatud on järgmised platvormid: %s",
    "Server version %s or higher is required." : "Nõutav on serveri versioon %s või suurem.",
    "Server version %s or lower is required." : "Serveri versioon %s või madalam on nõutav.",
    "Logged in account must be an admin, a sub admin or gotten special right to access this setting" : "Sisselogitud kasutajakonto peab olema peakasutajate või selle alamgrupi liige või omama eraldi õigust selle seadustuse muutmiseks",
    "Your current IP address doesn't allow you to perform admin actions" : "Sinu praeguselt IP-posti aadressilt ei saa teha haldustoiminguid",
    "Logged in account must be an admin or sub admin" : "Sisselogitud kasutajakonto peab olema peakasutajate või selle alamgrupi liige",
    "Logged in account must be an admin" : "Sisselogitud kasutajakonto peab olema peakasutajate grupi liige",
    "Wiping of device %s has started" : "Andmete kustutamine seadmes „%s“ algas",
    "Wiping of device »%s« has started" : "Andmete kustutamine seadmes „%s“ algas",
    "»%s« started remote wipe" : "„%s“ alustas kaugseadme andmete kustutamist",
    "Device or application »%s« has started the remote wipe process. You will receive another email once the process has finished" : "„%s“ seade või rakendus on alustanud kaugkustutamise protsessi. Selle lõppemisel saad veel ühe teavitava e-kirja",
    "Wiping of device %s has finished" : "Andmete kustutamine seadmes „%s“ lõppes",
    "Wiping of device »%s« has finished" : "Andmete kustutamine seadmes „%s“ lõppes",
    "»%s« finished remote wipe" : "„%s“ lõpetas kaugseadme andmete kustutamise",
    "Device or application »%s« has finished the remote wipe process." : "„%s“ seade või rakendus on lõpetanud kaugkustutamise protsessi.",
    "Remote wipe started" : "Kaugkustutamine on alanud",
    "A remote wipe was started on device %s" : "„%s“ seadme kaugkustutamine on alanud",
    "Remote wipe finished" : "Kaugkustutamine on lõppenud",
    "The remote wipe on %s has finished" : "„%s“ seadme kaugkustutamine on lõppenud",
    "Authentication" : "Autentimine",
    "Unknown filetype" : "Tundmatu failitüüp",
    "Invalid image" : "Vigane pilt",
    "Avatar image is not square" : "Avatari pilt pole ruut",
    "Files" : "Failid",
    "View profile" : "Vaata profiili",
    "same time" : "samas ajas",
    "_%nh_::_%nh_" : ["%n t","%n t"],
    "_%nm_::_%nm_" : ["%n min","%n min"],
    "%s ahead" : "%s ees",
    "%s behind" : "%s taga",
    "Local time: %s" : "Kohalik aeg: %s",
    "today" : "täna",
    "tomorrow" : "homme",
    "yesterday" : "eile",
    "_in %n day_::_in %n days_" : ["%n päeva pärast","%n päeva pärast"],
    "_%n day ago_::_%n days ago_" : ["%n päev tagasi","%n päeva tagasi"],
    "next month" : "järgmine kuu",
    "last month" : "viimasel kuul",
    "_in %n month_::_in %n months_" : ["%n kuu pärast","%n kuu pärast"],
    "_%n month ago_::_%n months ago_" : ["%n kuu eest","%n kuu eest"],
    "next year" : "järgmine aasta",
    "last year" : "viimasel aastal",
    "_in %n year_::_in %n years_" : ["%n aasta pärast","%n aasta pärast"],
    "_%n year ago_::_%n years ago_" : ["%n aasta tagasi","%n aastat tagasi"],
    "_in %n hour_::_in %n hours_" : ["%n tunni pärast","%n tunni pärast"],
    "_%n hour ago_::_%n hours ago_" : ["%n tund tagasi","%n tundi tagasi"],
    "_in %n minute_::_in %n minutes_" : ["%n minuti pärast","%n minuti pärast"],
    "_%n minute ago_::_%n minutes ago_" : ["%n minut tagasi","%n minutit tagasi"],
    "in a few seconds" : "mõne sekundi jooksul",
    "seconds ago" : "sekundit tagasi",
    "Empty file" : "Tühi fail",
    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Moodulit tunnusega „%s“ pole pole olemas. Palun taga see oma rakenduste seadistustest või võta ühendust peakasutajaga.",
    "No file conversion providers available" : "Ühtegi teisendusteenuse pakkujat pole saadaval",
    "File is too large to convert" : "Fail on teisendamiseks liiga suur",
    "Destination does not match conversion extension" : "Sihtmeedia ei vasta teisendamislaiendile",
    "Could not convert file" : "Faili teisendamine ei õnnestu",
    "Destination does not exist" : "Sihtmeediat pole olemas",
    "Destination is not creatable" : "Sihtmeedia pole loodav",
    "Dot files are not allowed" : "Punktiga failid pole lubatud",
    "%1$s (renamed)" : "%1$s (nimi on muudetud)",
    "renamed file" : "muudetud nimega fail",
    "\"%1$s\" is a forbidden file or folder name." : "„%1$s“ on keelatud faili- või kaustanimi.",
    "\"%1$s\" is a forbidden prefix for file or folder names." : "„%1$s“ on keelatud faili- või kaustanime eesliide.",
    "\"%1$s\" is not allowed inside a file or folder name." : "„%1$s“ pole faili- või kaustanimes lubatud.",
    "\"%1$s\" is a forbidden file type." : "„%1$s“ on keelatud failitüüp.",
    "Filenames must not end with \"%1$s\"." : "Failinimede lõpus ei tohi olla „%1$s“.",
    "Invalid parent path" : "Vigane ülemkaust",
    "File already exists" : "Fail on juba olemas",
    "Invalid path" : "Vigane kausta asukoht",
    "Failed to create file from template" : "Ei saa luua mallist faili",
    "Templates" : "Mallid",
    "Storage %s cannot be moved" : "„%s“ andmeruumi ei saa teisaldada",
    "Moving a share (%s) into a shared folder is not allowed" : "Jaosmeedia (%s) teisaldamine jaoskausta pole lubatud",
    "Moving a storage (%s) into a shared folder is not allowed" : "Andmeruumi (%s) teisaldamine jaoskausta pole lubatud",
    "Moving a share (%s) into another share (%s) is not allowed" : "Jaosmeedia (%s) teisaldamine teise jaosmeediasse (%s) pole lubatud",
    "Moving a share (%s) into another storage (%s) is not allowed" : "Jaosmeedia (%s) teisaldamine teise andmeruumi (%s) pole lubatud",
    "Moving a storage (%s) into a share (%s) is not allowed" : "Andmeruumi (%s) teisaldamine jaosmeediasse (%s) pole lubatud",
    "Moving a storage (%s) into another storage (%s) is not allowed" : "Andmeruumi (%s) teisaldamine andmeruumi (%s) pole lubatud",
    "Path contains invalid segments" : "Asukohas on vigaseid segmente",
    "Filename is a reserved word" : "Failinimi on reserveeritud sõna",
    "Filename contains at least one invalid character" : "Failinimes on vähemalt üks keelatud märk",
    "Filename is too long" : "Failinimi on liiga pikk",
    "Empty filename is not allowed" : "Tühi failinimi pole lubatud",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "Kuna „appinfo“ faili pole võimalik lugeda, siis „%s“ rakendust ei saa paigaldada.",
    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "Kuna ta pole ühilduv selle serveri versiooniga, siis „%s“ rakendust ei saa paigaldada.",
    "__language_name__" : "Eesti",
    "This is an automatically sent email, please do not reply." : "See on automaatselt saadetud e-kiri, palun ära vasta.",
    "Help & privacy" : "Abiteave ja privaatsus",
    "Appearance and accessibility" : "Välimus ja hõlpsus",
    "Apps" : "Rakendused",
    "Personal settings" : "Isiklikud seaded",
    "Administration settings" : "Administreerimise seaded",
    "Settings" : "Seaded",
    "Log out" : "Logi välja",
    "Accounts" : "Kasutajakontod",
    "Bluesky" : "Bluesky",
    "View %s on Bluesky" : "Vaata Bluesky's: %s",
    "Email" : "E-post",
    "Mail %s" : "E-post %s",
    "Fediverse" : "Födiversum",
    "View %s on the fediverse" : "Vaata Födiversumis: %s",
    "Phone" : "Telefon",
    "Call %s" : "Helista: %s",
    "Twitter" : "X / Twitter",
    "View %s on Twitter" : "Vaata X-is / Twitteris: %s",
    "Website" : "Veebileht",
    "Visit %s" : "Külasta veebilehte: %s",
    "Address" : "Aadress",
    "Profile picture" : "Profiilipilt",
    "About" : "Info",
    "Display name" : "Kuvatav nimi",
    "Headline" : "Alapealkiri",
    "Organization" : "Organisatsioon",
    "Role" : "Roll",
    "Pronouns" : "Asesõnad pöördumisel",
    "Unknown account" : "Tundmatu kasutajakonto",
    "Additional settings" : "Lisaseaded",
    "Enter the database Login and name for %s" : "Andmebaasi kasutajanimi ning nimi %si jaoks",
    "Enter the database Login for %s" : "Sisesta  andmebaasi %s kasutajatunnus",
    "Enter the database name for %s" : "Sisesta  andmebaasi %s nimi",
    "You cannot use dots in the database name %s" : "Sa ei tohi kasutada „%s“ andmebaasi nimes punkte",
    "MySQL Login and/or password not valid" : "MySQLi andmebaasi kasutajatunnus ja/või salasõna pole õiged",
    "You need to enter details of an existing account." : "Sa pead sisestama olemasoleva konto andmed.",
    "Oracle connection could not be established" : "Ei suuda luua ühendust Oracle baasiga",
    "Oracle Login and/or password not valid" : "Oracle andmebaasi kasutajatunnus ja/või salasõna pole õiged",
    "PostgreSQL Login and/or password not valid" : "PostgreSQLi andmebaasi kasutajatunnus ja/või salasõna pole õiged",
    "macOS is not supported and %s will not work properly on this platform." : "Mac OS X ei ole toetatud ja %s ei pruugi korralikult toimida sellel platvormil.",
    "For the best results, please consider using a GNU/Linux server instead." : "Parema tulemuse saavitamiseks palun kaalu serveris GNU/Linux kasutamist.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Tundub, et %s server töötab 32-bitises PHP käituskeskkonnas ja „open_basedir“ on php.ini failis seadistatud. Kui failide suurus on üle 4 GB, siis võib tekkida probleeme ning antud lahenduse kasutamist me ei soovita.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Palun eemalda oma serveri seadistustest php.ini failist „open_basedir“ seadistus või võta kasutusele 64-bitisel platvormil põhinev PHP versioon.",
    "Set an admin Login." : "Lisa peakasutaja kasutajanimi.",
    "Set an admin password." : "Lisa peakasutaja salasõna.",
    "Cannot create or write into the data directory %s" : "Ei õnnestu luua „%s“ andmekausta või sealt lugeda",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Jagamise tagarakend %s peab kasutusele võtma OCP\\Share_Backend liidese",
    "Sharing backend %s not found" : "Jagamise tagarakendit %s ei leitud",
    "Sharing backend for %s not found" : "Jagamise tagarakendit %s jaoks ei leitud",
    "%1$s shared %2$s with you" : "%1$s jagas sinuga: %2$s",
    "Open %s" : "Ava %s ",
    "%1$s via %2$s" : "%1$s %2$s kaudu",
    "%1$s shared %2$s with you and wants to add:" : "%1$s jagas sinuga %2$s ning soovib lisada:",
    "%1$s shared %2$s with you and wants to add" : "%1$s jagas sinuga %2$s ning soovib lisada",
    "%s added a note to a file shared with you" : "%s jagas koos sulle jagatud failiga ka märget",
    "Passwords are enforced for link and mail shares" : "Linkide ja e-posti teel levitatava jaosmeedia puhul on salasõnade kasutamine nõutav",
    "Share recipient is not a valid user" : "Jaosmeedia vastuvõtja pole korrektne kasutaja",
    "Share recipient is not a valid group" : "Jaosmeedia vastuvõtja pole korrektne grupp",
    "Share recipient should be empty" : "Jaosmeedia vastuvõtja peaks jääma tühjaks",
    "Share recipient should not be empty" : "Jaosmeedia vastuvõtja ei tohi jääda tühjaks",
    "Share recipient is not a valid circle" : "Jaosmeedia vastuvõtja pole korrektne tiim",
    "Unknown share type" : "Tundmatu jagamise tüüp",
    "Share initiator must be set" : "Jagamise alustaja peab olema määratud",
    "Cannot share with yourself" : "Sa ei saa iseendale jagada",
    "Shared path must be set" : "Jagamise asukoht peab olema teada",
    "Shared path must be either a file or a folder" : "Jagamise asukoht peab olema kas kaust või fail",
    "You cannot share your root folder" : "Sa ei saa juurkausta jagada",
    "You are not allowed to share %s" : "Sul pole lubatud %s jagada",
    "Valid permissions are required for sharing" : "Jagamiseks peavad olema korrektsed õigused",
    "File shares cannot have create or delete permissions" : "Jaosfailidel ei saa olla loomis- või kustutamisõigusi",
    "Cannot increase permissions of %s" : "Ei saa %s õigusi suurendada",
    "Shares need at least read permissions" : "Jaosmeedial peab olema vähemalt lugemisõigus",
    "Files cannot be shared with delete permissions" : "Kustutusõigustega faile ei saa jagada",
    "Files cannot be shared with create permissions" : "Loomisõigustega faile ei saa jagada",
    "Expiration date is in the past" : "Aegumise kuupäev on minevikus",
    "Expiration date is enforced" : "Aegumiskuupäev on kasutusel",
    "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Aegumist ei saa lisada kaugemale, kui %n päev tulevikus.","Aegumist ei saa lisada kaugemale, kui %n päeva tulevikus."],
    "Sharing is only allowed with group members" : "Jagamine on lubatud vaid grupi liikmetega",
    "Sharing %s failed, because this item is already shared with the account %s" : "%s jagamine ei õnnestunud, kuna seda objekti on juba jagatud kontoga %s",
    "Group sharing is now allowed" : "Grupile jagamine on nüüd lubatud",
    "Sharing is only allowed within your own groups" : "Jagamine on lubatud vaid sinu oma grupi liikmetega",
    "Path is already shared with this group" : "Asukoht on selle grupiga juba jagatud",
    "Link sharing is not allowed" : "Lingi jagamine pole lubatud",
    "Public upload is not allowed" : "Avalik üleslaadimine pole lubatud",
    "You cannot share a folder that contains other shares" : "Sa ei saa jagada jaoskausta, kus sisalduvad muud jaoskaustad",
    "Sharing is disabled" : "Jagamine pole kasutusel",
    "Sharing is disabled for you" : "Jagamine pole sinu jaoks kasutusel",
    "Cannot share with the share owner" : "Sa ei saa jagada jaosmeedia omanikule",
    "Share does not have a full ID" : "Jaosmeedial on täismahuline tunnus puudu",
    "Cannot change share type" : "Sa ei saa muuta jaosmeedia tüüpi",
    "Can only update recipient on user shares" : "Kasutaja jaosmeedia saajat ei õnnestu uuendada",
    "Cannot change target of link share" : "Lingiga jagamise objekti muutmine ei õnnestu",
    "Invalid share recipient" : "Vigane jaosmeedia vastuvõtja",
    "Group \"%s\" does not exist" : "„%s“ gruppi pole olemas",
    "The requested share does not exist anymore" : "Soovitud jagamist enam ei eksisteeri",
    "The requested share comes from a disabled user" : "Soovitud jaosmeedia on loonud blokeeritud kasutaja",
    "The user was not created because the user limit has been reached. Check your notifications to learn more." : "Kuna kasutajate arvu ülempiir on käes, siis uus kasutaja jäi lisamata. Lisateavet leiad oma teavitustest.",
    "Could not find category \"%s\"" : "Ei leia kategooriat „%s“",
    "Input text" : "Sisendtekst",
    "The input text" : "Sisendtekst",
    "Cannot generate more than 12 images" : "Ei saa luua üle 12 pildi",
    "Cannot generate less than 1 image" : "Ei saa luua alla 1 pildi",
    "Sunday" : "Pühapäev",
    "Monday" : "Esmaspäev",
    "Tuesday" : "Teisipäev",
    "Wednesday" : "Kolmapäev",
    "Thursday" : "Neljapäev",
    "Friday" : "Reede",
    "Saturday" : "Laupäev",
    "Sun." : "P",
    "Mon." : "E",
    "Tue." : "T",
    "Wed." : "K",
    "Thu." : "N",
    "Fri." : "R",
    "Sat." : "L",
    "Su" : "P",
    "Mo" : "E",
    "Tu" : "T",
    "We" : "K",
    "Th" : "N",
    "Fr" : "R",
    "Sa" : "L",
    "January" : "Jaanuar",
    "February" : "Veebruar",
    "March" : "Märts",
    "April" : "Aprill",
    "May" : "Mai",
    "June" : "Juuni",
    "July" : "Juuli",
    "August" : "August",
    "September" : "September",
    "October" : "Oktoober",
    "November" : "November",
    "December" : "Detsember",
    "Jan." : "Jaan.",
    "Feb." : "Veebr.",
    "Mar." : "Märts.",
    "Apr." : "Apr.",
    "May." : "Mai.",
    "Jun." : "Juuni.",
    "Jul." : "Juuli.",
    "Aug." : "Aug.",
    "Sep." : "Sept.",
    "Oct." : "Okt.",
    "Nov." : "Nov.",
    "Dec." : "Dets.",
    "A valid password must be provided" : "Sisesta nõuetele vastav salasõna",
    "The Login is already being used" : "See kasutajanimi on juba kasutusel",
    "Could not create account" : "Kasutajakonto loomine ei õnnestunud",
    "Only the following characters are allowed in an Login: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Kasutajanimes on lubatud ainult järgmised tähemärgid: „a-z“, „A-Z“, „0-9“, ja „_.@-'“",
    "A valid Login must be provided" : "Palun sisesta korrektne kasutajanimi",
    "Login contains whitespace at the beginning or at the end" : "Kasutajanime alguses või lõpus on tühik",
    "Login must not consist of dots only" : "Kasutajanimi ei tohi koosneda ainult punktidest",
    "Username is too long" : "Kasutajanimi on liiga pikk",
    "Login is invalid because files already exist for this user" : "See kasutajanimi ei sobi, kuna sellise kasutaja faile on juba olemas",
    "Account disabled" : "Konto pole kasutusel",
    "Login canceled by app" : "Rakendus katkestas sisselogimise",
    "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "„%1$s“ rakendust ei saa paigaldada, sest järgnev sõltuvus on puudu: %2$s",
    "a safe home for all your data" : "turvaline koht sinu andmetele",
    "Application is not enabled" : "Rakendus pole sisse lülitatud",
    "Authentication error" : "Autentimise viga",
    "Token expired. Please reload page." : "Kontrollkood aegus. Paelun laadi leht uuesti.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Ühtegi andmebaasi (sqlite, mysql või postgresql) draiverit pole paigaldatud.",
    "Cannot write into \"config\" directory." : "Pole õigust kirjutada „config“ kausta.",
    "This can usually be fixed by giving the web server write access to the config directory. See %s" : "Tavaliselt saad selle lahendada andes veebiserverile õigused seadistuse kausta kirjutamiseks. Vaata siia: %s",
    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Aga kui soovid, et config.pho seadistuste fail ei peaks olema veebiserveri poolt muudetav, siis palun määra seadistusvõtme „config_is_read_only“ väärtuseks true. Lisateavet leiad: %s",
    "Cannot create \"data\" directory." : "„data“ kausta loomine ei õnnestunud.",
    "This can usually be fixed by giving the web server write access to the root directory. See %s" : "Tavaliselt saad selle lahendada andes veebiserverile õigused juurkausta kirjutamiseks. Vaata siia: %s",
    "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "Tavaliselt saad õiguste vea lahendada andes veebiserverile õigused juurkausta kirjutamiseks. Vaata siia: %s",
    "Your data directory is not writable." : "Sinu serveri andmekaust pole kirjutatav.",
    "Setting locale to %s failed." : "Ei õnnestunud määrata lokaadi väärtuseks „%s“.",
    "Please install one of these locales on your system and restart your web server." : "Palun paigalda mõni neist lokaatidest oma serverisse ning taaskäivita veebiserver.",
    "PHP module %s not installed." : "PHP moodulit %s pole paigaldatud.",
    "Please ask your server administrator to install the module." : "Palu oma serveri haldajal moodul paigadalda.",
    "PHP setting \"%s\" is not set to \"%s\"." : "PHP seadistuse „%s“ väärtuseks ei ole „%s“.",
    "Adjusting this setting in php.ini will make Nextcloud run again" : "Selle seadistuse kohendamine php.ini failis võimaldab sul Nextcloudi uuesti tööle saada",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP on seadistatud eemaldama „inline“ dokumendi blokke. See muudab mõned tuumikrakendused kasutamatuteks.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "See on tõenäoliselt põhjustatud puhver/kiirendist nagu Zend OPcache või eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "PHP moodulid on paigaldatud, kuid neid näitatakse endiselt kui puuduolevad?",
    "Please ask your server administrator to restart the web server." : "Palu oma serveri haldajal veebiserver taaskäivitada.",
    "The required %s config variable is not configured in the config.php file." : "Nõutav seadistuste muutuja „%s“ puudub sonfig.php failist.",
    "Please ask your server administrator to check the Nextcloud configuration." : "Palu oma serveri haldajal Nextcloudi seadistusi kontrollida.",
    "Your data directory is readable by other people." : "Sinu andmete kaust on loetav teiste kasutajate poolt.",
    "Please change the permissions to 0770 so that the directory cannot be listed by other people." : "Palun muuda kausta õigused 0770-ks, et kausta sisu poleks teistele kasutajatele nähtav.",
    "Your data directory must be an absolute path." : "Andmekausta asukoht peab olema absoluutne aadress.",
    "Check the value of \"datadirectory\" in your configuration." : "Palun kontrolli „datadirectory“ väärtust selle paigalduse seadistustes.",
    "Your data directory is invalid." : "Sinu andmekaust on vigane.",
    "Ensure there is a file called \"%1$s\" in the root of the data directory. It should have the content: \"%2$s\"" : "Palun taga, et andmete juurkaustas leidub fail „%1$s“, mille sisuks on „%2$s“",
    "Action \"%s\" not supported or implemented." : "„%s“ tegevus pole toetatud või implementeeritud.",
    "Authentication failed, wrong token or provider ID given" : "Autentimine ei õnnestunud - kas tunnusluba või teenusepakkuja tunnus on vale",
    "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "Päringu lõpetamiseks on puudu järgmised parameetrid: „%s“",
    "ID \"%1$s\" already used by cloud federation provider \"%2$s\"" : "„%1$s“ tunnus on juba kasutusel liitpilve serveris „%2$s“",
    "Cloud Federation Provider with ID: \"%s\" does not exist." : "Liitpilve teenusepakkujat tunnusega „%s“ pole olemas.",
    "Could not obtain lock type %d on \"%s\"." : "Ei suutnud hankida %d tüüpi lukustust asukohas „%s“.",
    "Storage unauthorized. %s" : "Andmeruum on autoriseerimata. %s",
    "Storage incomplete configuration. %s" : "Andmeruumi poolik seadistus. %s",
    "Storage connection error. %s" : "Viga andmeruumi ühenduse loomisel. %s",
    "Storage is temporarily not available" : "Salvestusruum pole ajutiselt kättesaadav",
    "Storage connection timeout. %s" : "Aegumine andmeruumi ühenduse loomisel. %s",
    "Analyze images" : "Piltide analüüs",
    "Ask a question about the given images." : "Küsi antud piltide kohta",
    "Images" : "Pildid",
    "Images to ask a question about" : "Pildid, mille kohta soovid küsida",
    "Question" : "Küsimus",
    "What to ask about the images." : "Seda saad pildi kohta küsida.",
    "Generated response" : "Loodud vastus",
    "The answer to the question" : "Vastus küsimusele",
    "Audio chat" : "Häälvestlus",
    "Voice chat with the assistant" : "Häälvestlus Abilisega",
    "System prompt" : "Süsteemi viip",
    "Define rules and assumptions that the assistant should follow during the conversation." : "Määratle reeglid ja eeldused, mida Abiline peaks vestluse kestel järgima.",
    "Chat voice message" : "Vestluse häälsõnum",
    "Describe a task that you want the assistant to do or ask a question." : "Kirjelda seda, mida soovid Abilisele ülesandeks teha või lihtsalt küsi midagi.",
    "Chat history" : "Vestluse ajalugu",
    "The history of chat messages before the current message, starting with a message by the user." : "Kasutaja sõnumiga algav vestluse ajalugu enne praegust sõnumit.",
    "Input transcript" : "Sisendi üleskirjutus",
    "Transcription of the audio input" : "Helisisendi üleskirjutus",
    "Response voice message" : "Vastuse häälsõnum",
    "The generated voice response as part of the conversation" : "Loodud häälvastus vestluse osana",
    "Output transcript" : "Väljundi üleskirjutus",
    "Transcription of the audio output" : "Heliväljundi üleskirjutus",
    "Transcribe audio" : "Kirjuta heli üles",
    "Transcribe the things said in an audio" : "Kirjuta üles helifailis kuuldav jutt",
    "Audio input" : "Helisisend",
    "The audio to transcribe" : "Üleskirjutatav helifail",
    "Transcription" : "Üleskirjutus",
    "The transcribed text" : "Üleskirjutatud tekst",
    "Chat by voice with an agent" : "Räägi agendiga",
    "Describe a task that you want the agent to do or ask a question." : "Kirjelda seda, mida soovid agendile ülesandeks teha või lihtsalt küsi midagi.",
    "Confirmation" : "Kinnitus",
    "Whether to confirm previously requested actions: 0 for denial and 1 for confirmation." : "Kas peaksime eelmised tegevuse kinnitama: keeldumist märgib 0 ja nõustumist 1.",
    "Conversation token" : "Vestluse tunnusluba",
    "A token representing the conversation." : "Tunnusluba vestluse tuvastamiseks.",
    "The new conversation token" : "Vestluse uus tunnusluba",
    "Send this along with the next interaction." : "Saada see kaasa järgmise päringuga.",
    "Requested actions by the agent" : "Ülesanded tehisaru agendile",
    "Actions that the agent would like to carry out in JSON format." : "Tehisaru agendile antavad ülesanded JSON-vormingus.",
    "Chat with an agent" : "Vestle robotagendiga",
    "Chat message" : "Vestluse sõnum",
    "A chat message to send to the agent." : "Robotagendile saadetav sõnum.",
    "The response from the chat model." : "Vastus tehisarupõhise vestluse mudelilt.",
    "Context write" : "Kontekstuaalne kirjutamine",
    "Writes text in a given style based on the provided source material." : "Kirjutab etteantud lähtematerjali lausel teksti üles.",
    "Writing style" : "Kirjutamisstiil",
    "Demonstrate a writing style that you would like to immitate" : "Näita sellist kirjutamisstiili, mida tahad jäljendada",
    "Source material" : "Lähtematerjal",
    "The content that would like to be rewritten in the new writing style" : "Sisu, mida tahaksid uues stiilis ümber kirjutada",
    "Generated text" : "Koostatud tekst",
    "The generated text with content from the source material in the given style" : "Antud stiilis lähtematerjali alusel koostatud tekst",
    "Emoji generator" : "Emojide looja",
    "Takes text and generates a representative emoji for it." : "Võtab aluseks teksti ja lood selle alusel emoji.",
    "The text to generate an emoji for" : "Lähtetekst, millest lood emoji",
    "Generated emoji" : "Loodud emoji",
    "The generated emoji based on the input text" : "Sisestatud teksti alusel loodud emoji",
    "Optical character recognition" : "Optiline märgituvastus",
    "Extract text from files like images or PDFs" : "Tuvasta tekst erinevatest failidest, sh pildid ja PDF-failid",
    "Input files" : "Sisendfailid",
    "The files to extract text from" : "Failid, millest tahad tuvastada teksti",
    "Output texts" : "Väljundtekstid",
    "The texts that were extracted from the files" : "Tekstid, mis on etteantud failidest tuvastatud",
    "Generate image" : "Pildiloome",
    "Generate an image from a text prompt" : "Loo tekstisisendist pilt",
    "Prompt" : "Sisendvorm",
    "Describe the image you want to generate" : "Kirjelda loodavat pilti",
    "Number of images" : "Piltide arv",
    "How many images to generate" : "Mitu pilti peaksime tekitama",
    "Output images" : "Väljundpildid",
    "The generated images" : "Loodud pildid",
    "Generate speech" : "Koosta kõne",
    "Generate speech from a transcript" : "Koosta üleskirjutusest kõne",
    "Write transcript that you want the assistant to generate speech from" : "Kirjuta üles see, mille alusel tahad Abilisel lasta koostada kõne",
    "Output speech" : "Kõneväljund",
    "The generated speech" : "Koostatud kõne",
    "Describe a task that you want the assistant to do or ask a question" : "Kirjelda seda, mida soovid Abilisele ülesandeks teha või lihtsalt küsi midagi.",
    "Generated reply" : "Koostatud vastus",
    "The generated text from the assistant" : "Abilise poolt koostatud tekst",
    "Change Tone" : "Teksti tooni muutmine",
    "Change the tone of a piece of text." : "Muuda antud teksti tonaalsust.",
    "Write a text that you want the assistant to rewrite in another tone." : "Kirjuta üles see, mille tonaalsust tahad Abilisel lasta ümber kirjutada.",
    "Desired tone" : "Soovitud toon",
    "In which tone should your text be rewritten?" : "Mis toonis peaks tekst olema ümberkirjutatud?",
    "The rewritten text in the desired tone, written by the assistant:" : "Abilise poolt soovitud toonis ümberkirjutatud tekst:",
    "Chat" : "Vestle",
    "Chat with the assistant" : "Vestle Abilisega",
    "The history of chat messages before the current message, starting with a message by the user" : "Kasutaja sõnumiga algav vestluse ajalugu enne praegust sõnumit",
    "Response message" : "Sõnumi vastus",
    "The generated response as part of the conversation" : "Loodud vastus vestluse osana",
    "Formalize text" : "Muuda tekst ametlikuks",
    "Takes a text and makes it sound more formal" : "Sisestatud teksti vormistamine ametlikuna",
    "Write a text that you want the assistant to formalize" : "Sisesta tekst, mille Abiline peaks tegema ametlikumaks",
    "Formalized text" : "Ametlikus vormis tekst",
    "The formalized text" : "Mitteametlikus vormis tekst",
    "Generate a headline" : "Alapealkirja loomine",
    "Generates a possible headline for a text." : "Võimaldab luua teksti põhjal kokkuvõtliku alapealkirja.",
    "Original text" : "Lähtetekst",
    "The original text to generate a headline for" : "Lähtetekst, millest lood kokkuvõtliku alapealkirja",
    "The generated headline" : "Loodud alapealkiri",
    "Proofread" : "Keelekorrektuur",
    "Proofreads a text and lists corrections" : "Võimaldab teha tekstide ja loendite korrektuuri",
    "Text" : "Tekst",
    "The text to proofread" : "Keelekorrektuuri vajav tekst",
    "Corrections" : "Korrektuuris tehtud parandused",
    "The corrections that should be made in your text" : "Korrektuuris tehtud parandused, mis peaks sinu teksti lisanduma",
    "Reformulate text" : "Teksti sõnastuse mutmine",
    "Takes a text and reformulates it" : "Sisendina antud tekst saab ümbersõnastatud",
    "Write a text that you want the assistant to reformulate" : "Sisesta tekst, mille Abiline peaks ümbersõnastama",
    "Reformulated text" : "Ümbersõnastatud tekst",
    "The reformulated text, written by the assistant" : "Abilise poolt ümbersõnastatud tekst",
    "Simplify text" : "Teksti lihtsustamine",
    "Takes a text and simplifies it" : "Sisendina antud tekst saab lihtsustatud",
    "Write a text that you want the assistant to simplify" : "Sisesta tekst, mille Abiline peaks tegema lihtsamaks",
    "Simplified text" : "Lihtsustatud tekst",
    "The simplified text" : "Lihtsustatud tekst",
    "Summarize" : "Teksti kokkuvõte",
    "Summarizes a text" : "Sisendina antud tekstist tehakse kokkuvõte",
    "The original text to summarize" : "Algme tekst, millest peaks tegema kokkuvõtte",
    "Summary" : "Kokkuvõte",
    "The generated summary" : "Koostatud kokkuvõte",
    "Extract topics" : "Teemade esiletoomine",
    "Extracts topics from a text and outputs them separated by commas" : "Sisendina antud tekstist leitakse teemad, mis väljastatakse komadega eraldatud loendina",
    "The original text to extract topics from" : "Lähtetekst, millest teemad tuvastatakse",
    "Topics" : "Teemad",
    "The list of extracted topics" : "Tuvastatud teemade loend",
    "Translate" : "Tõlgi",
    "Translate text from one language to another" : "Tõlgi teksti ühest keelest teise",
    "Origin text" : "Lähtetekst",
    "The text to translate" : "Tõlgitav tekst",
    "Origin language" : "Lähtekeel",
    "The language of the origin text" : "Lähteteksti keel",
    "Target language" : "Tõlkekeel",
    "The desired language to translate the origin text in" : "Keel, millesse lähteteksti tõlgime",
    "Result" : "Tulemus",
    "The translated text" : "Tõlgitud tekst",
    "Generate headline" : "Alapealkirja loomine",
    "Organisation" : "Organisatsioon",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk!" : "Mac OS X ei ole toetatud ja %s ei pruugi korralikult toimida sellel platvormil. Kasuta seda omal vastutusel!",
    "Login is too long" : "Kasutajanimi on liiga pikk",
    "Cannot write into \"apps\" directory." : "Pole õigust kirjutada „apps“ kausta.",
    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Tavaliselt saad selle lahendada andes veebiserverile õigused rakenduste kausta kirjutamiseks. Alternatiivina võid ka Nextcloudi rakendustepoe kasutamise keelata.",
    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> muutuja väärtus on hetkel <code>%s</code>, pigem eeldaks väärtust <code>0</code>.",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Vea parandamiseks muuda oma veebiserveri php.ini failis <code>mbstring.func_overload</code> väärtuseks <code>0</code>."
},
"nplurals=2; plural=(n != 1);");
